@@ -156,23 +156,23 @@ static const FwdTxfm2dFunc fwd_txfm_2d_N4_sse4_1_func[TX_SIZES_ALL] = {
 static const FwdTxfm2dFunc fwd_txfm_2d_avx512_func[TX_SIZES_ALL] = {
     NULL,
     NULL,
-    av1_fwd_txfm2d_16x16_avx512,
-    av1_fwd_txfm2d_32x32_avx512,
-    av1_fwd_txfm2d_64x64_avx512,
+    svt_av1_fwd_txfm2d_16x16_avx512,
+    svt_av1_fwd_txfm2d_32x32_avx512,
+    svt_av1_fwd_txfm2d_64x64_avx512,
     NULL,
     NULL,
     NULL,
     NULL,
-    av1_fwd_txfm2d_16x32_avx512,
-    av1_fwd_txfm2d_32x16_avx512,
-    av1_fwd_txfm2d_32x64_avx512,
-    av1_fwd_txfm2d_64x32_avx512,
+    svt_av1_fwd_txfm2d_16x32_avx512,
+    svt_av1_fwd_txfm2d_32x16_avx512,
+    svt_av1_fwd_txfm2d_32x64_avx512,
+    svt_av1_fwd_txfm2d_64x32_avx512,
     NULL,
     NULL,
     NULL,
     NULL,
-    av1_fwd_txfm2d_16x64_avx512,
-    av1_fwd_txfm2d_64x16_avx512,
+    svt_av1_fwd_txfm2d_16x64_avx512,
+    svt_av1_fwd_txfm2d_64x16_avx512,
 };
 
 static const FwdTxfm2dFunc fwd_txfm_2d_N2_avx512_func[TX_SIZES_ALL] = {
@@ -250,32 +250,6 @@ static const FwdTxfm2dFunc fwd_txfm_2d_N2_neon_func[TX_SIZES_ALL] = {
 
 #endif /* ARCH_AARCH64*/
 
-static const FwdTxfm2dFunc fwd_txfm_2d_N2_c_func[TX_SIZES_ALL] = {
-    svt_aom_transform_two_d_4x4_N2_c,   svt_aom_transform_two_d_8x8_N2_c,
-    svt_aom_transform_two_d_16x16_N2_c, svt_aom_transform_two_d_32x32_N2_c,
-    svt_aom_transform_two_d_64x64_N2_c, svt_av1_fwd_txfm2d_4x8_N2_c,
-    svt_av1_fwd_txfm2d_8x4_N2_c,        svt_av1_fwd_txfm2d_8x16_N2_c,
-    svt_av1_fwd_txfm2d_16x8_N2_c,       svt_av1_fwd_txfm2d_16x32_N2_c,
-    svt_av1_fwd_txfm2d_32x16_N2_c,      svt_av1_fwd_txfm2d_32x64_N2_c,
-    svt_av1_fwd_txfm2d_64x32_N2_c,      svt_av1_fwd_txfm2d_4x16_N2_c,
-    svt_av1_fwd_txfm2d_16x4_N2_c,       svt_av1_fwd_txfm2d_8x32_N2_c,
-    svt_av1_fwd_txfm2d_32x8_N2_c,       svt_av1_fwd_txfm2d_16x64_N2_c,
-    svt_av1_fwd_txfm2d_64x16_N2_c,
-};
-
-static const FwdTxfm2dFunc fwd_txfm_2d_N4_c_func[TX_SIZES_ALL] = {
-    svt_aom_transform_two_d_4x4_N4_c,   svt_aom_transform_two_d_8x8_N4_c,
-    svt_aom_transform_two_d_16x16_N4_c, svt_aom_transform_two_d_32x32_N4_c,
-    svt_aom_transform_two_d_64x64_N4_c, svt_av1_fwd_txfm2d_4x8_N4_c,
-    svt_av1_fwd_txfm2d_8x4_N4_c,        svt_av1_fwd_txfm2d_8x16_N4_c,
-    svt_av1_fwd_txfm2d_16x8_N4_c,       svt_av1_fwd_txfm2d_16x32_N4_c,
-    svt_av1_fwd_txfm2d_32x16_N4_c,      svt_av1_fwd_txfm2d_32x64_N4_c,
-    svt_av1_fwd_txfm2d_64x32_N4_c,      svt_av1_fwd_txfm2d_4x16_N4_c,
-    svt_av1_fwd_txfm2d_16x4_N4_c,       svt_av1_fwd_txfm2d_8x32_N4_c,
-    svt_av1_fwd_txfm2d_32x8_N4_c,       svt_av1_fwd_txfm2d_16x64_N4_c,
-    svt_av1_fwd_txfm2d_64x16_N4_c,
-};
-
 /**
  * @brief Unit test for fwd tx 2d avx2 functions:
  * - svt_av1_fwd_txfm2d_{4, 8, 16, 32, 64}x{4, 8, 16, 32, 64}_avx2
